@@ -9,38 +9,50 @@ import sys
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 
 try:
-    import utils.exceptions as exceptions
+    import pysql.utils.exceptions as exceptions
     import stdiomask
     import time
     import urllib.request
-    import packages.auth as auth
-    import packages.ddl_commands as ddl
-    import packages.dml_commands as dml
-    import data.info as info
-    import data.export as export
-    import data.imports as imports
-    import data.update as update
+    import pysql.packages.auth as auth
+    import pysql.packages.ddl_commands as ddl
+    import pysql.packages.dml_commands as dml
+    import pysql.data.info as info
+    import pysql.data.export as export
+    import pysql.data.imports as imports
+    import pysql.utils.update as update
+    import pysql.utils.user as user
 
 except:
     raise exceptions.PySQLPackageError()
 
-__version__ = "1.0.9"
+__version__ = "1.1.2"
 
 print(info.ascii_art)
 time.sleep(1)
 
-uname = input("Username: ")
-passwd = stdiomask.getpass(prompt = "Password: ")
+# check if a default user exists
+check = user.User().check_default_user()
 
-# authenticate input credentials
-authenticate = auth.Database(uname, passwd).authenticate()
-if authenticate is False:
-    print("\n[-] User could not be authenticated")
-    exit()
+if check is True:
+    # get default user's name
+    def_user = user.User().get_default_user()
+    print(f"\n[+] Default user {def_user[0]} authenticated")
+    uname = def_user[0]
+    passwd = def_user[1]
+
+else:
+    uname = input("Username: ")
+    passwd = stdiomask.getpass(prompt = "Password: ")
+
+    # authenticate input credentials
+    authenticate = auth.Database(uname, passwd).authenticate()
+    if authenticate is False:
+        print("\n[-] User could not be authenticated")
+        exit()
+
+    print(f"\n[+] User authenticated")
 
-print(f"\n[+] User authenticated")
 time.sleep(1)
-
 print(info.menu)
 
 # package class instances as objects for calling functions
@@ -55,10 +67,13 @@ db_use = False
 
 while (True):
 
-    user_input = input("pysql> ")
+    if db_use is True:
+        user_input = input(f"({current_db}) pysql> ")
+
+    else:
+        user_input = input("pysql> ")
 
     try:
-
         if user_input.lower() in ["-a", "about"]:
             print(info.about)
 
@@ -72,15 +87,17 @@ while (True):
         elif user_input.lower() in ["-c", "commands"]:
             print(info.commands)
 
+        elif user_input.lower() in ["-d", "def user"]:
+            print(info.default_user)
+
         elif user_input.lower() in ["-v", "version"]:
             print(__version__ + "\n")
 
-        elif user_input.lower() in ["-u", "update"]:
+        elif user_input.lower() in ["-u", "updates"]:
             gh_version = urllib.request.urlopen("https://raw.githubusercontent.com/Devansh3712/PySQL/main/pysql/__version__.py")
             gh_version = gh_version.read().decode("utf-8")
 
             if gh_version > __version__:
-
                 result = update.update_pysql()
 
                 if result is True:
@@ -93,6 +110,45 @@ while (True):
             else:
                 print(f"[+] PySQL is up-to-date\n")
 
+        elif user_input.lower() == "adduser":
+
+            if db_use is True:
+                _uname = input(f"({current_db}) pysql> Enter username: ")
+                _passwd = stdiomask.getpass(prompt = f"({current_db}) pysql> Enter password: ")
+
+            else:
+                _uname = input("pysql> Enter username: ")
+                _passwd = stdiomask.getpass(prompt = "pysql> Enter password: ")
+
+            result = user.User().add_default_user(_uname, _passwd)
+
+            if result is True:
+                print(f"[+] Default user {_uname} created\n")
+
+            else:
+                print(f"[-] Unable to create default user\n")
+
+        elif user_input.lower() == "removeuser":
+
+            if db_use is True:
+                _passwd = stdiomask.getpass(prompt = f"({current_db}) pysql> Enter password: ")
+
+            else:
+                _passwd = stdiomask.getpass(prompt = "pysql> Enter password: ")
+
+            def_user = user.User().get_default_user()
+            if _passwd == def_user[1]:
+                result = user.User().remove_default_user()
+
+                if result is True:
+                    print(f"[+] Default user {def_user[0]} removed\n")
+
+                else:
+                    print(f"[-] Unable to remove default user\n")
+
+            else:
+                print("[-] Unable to authenticate\n")
+
         elif user_input.lower() == "ddl":
             print(info.data_definition_language)
 
@@ -106,7 +162,13 @@ while (True):
                 print("[-] Unable to show databases\n")
 
         elif user_input.lower() == "createdb":
-            db_name = input("pysql> Enter database name: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
+
             result = ddl_obj.create_database(db_name)
 
             if result is True:
@@ -116,7 +178,13 @@ while (True):
                 print(f"[-] Unable to create database {db_name}\n")
 
         elif user_input.lower() == "usedb":
-            db_name = input("pysql> Enter database name: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
+
             result = ddl_obj.use_database(db_name)
 
             if result is True:
@@ -128,7 +196,12 @@ while (True):
                 print(f"[-] Unable to connect to database {db_name}\n")
 
         elif user_input.lower() == "dropdb":
-            db_name = input("pysql> Enter database name: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
 
             result = ddl_obj.drop_database(db_name)
 
@@ -157,10 +230,10 @@ while (True):
         elif user_input.lower() == "createtb":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                args = input("pysql> Enter table details: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                args = input(f"({current_db}) pysql> Enter table details: ")
                 args = args.split(",")
-                result = ddl_obj.create_table(tb_name, args)
+                result = ddl_obj.create_table(current_db, tb_name, args)
 
                 if result is True:
                     print(f"[+] Created table {tb_name}\n")
@@ -174,7 +247,7 @@ while (True):
         elif user_input.lower() == "droptb":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
                 result = ddl_obj.drop_table(current_db, tb_name)
 
                 if result is True:
@@ -189,7 +262,7 @@ while (True):
         elif user_input.lower() == "trunctb":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
                 result = ddl_obj.truncate_table(current_db, tb_name)
 
                 if result is True:
@@ -204,7 +277,7 @@ while (True):
         elif user_input.lower() == "desctb":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
                 result = ddl_obj.desc_table(current_db, tb_name)
 
                 if result:
@@ -219,8 +292,8 @@ while (True):
         elif user_input.lower() == "altertb":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                args = input("pysql> Enter arguments: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                args = input(f"({current_db}) pysql> Enter arguments: ")
                 args = args.split(",")
                 result = ddl_obj.alter_table(current_db, tb_name, args)
 
@@ -239,9 +312,9 @@ while (True):
         elif user_input.lower() == "select":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                columns = input("pysql> Enter selection columns: ")
-                args = input("pysql> Enter arguments: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                columns = input(f"({current_db}) pysql> Enter selection columns: ")
+                args = input(f"({current_db}) pysql> Enter arguments: ")
                 result = dml_obj.select(current_db, tb_name, columns, args)
 
                 if result:
@@ -256,8 +329,8 @@ while (True):
         elif user_input.lower() in ["insert -s", "insert"]:
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                args = input("pysql> Enter values: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                args = input(f"({current_db}) pysql> Enter values: ")
                 result = dml_obj.insert(current_db, tb_name, args)
 
                 if result is True:
@@ -272,12 +345,12 @@ while (True):
         elif user_input.lower() == "insert -m":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                num = int(input("pysql> Enter number of records: "))
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                num = int(input(f"({current_db}) pysql> Enter number of records: "))
                 flag = True
 
                 for records in range (num):
-                    args = input("pysql> Enter values: ")
+                    args = input(f"({current_db}) pysql> Enter values: ")
                     result = dml_obj.insert(current_db, tb_name, args)
 
                     if result is False:
@@ -294,8 +367,8 @@ while (True):
         elif user_input.lower() == "insert -f":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                path = input("pysql> Enter path to CSV file: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                path = input(f"({current_db}) pysql> Enter path to CSV file: ")
                 result = dml_obj.insert_file(current_db, tb_name, path)
 
                 if result is True:
@@ -310,9 +383,9 @@ while (True):
         elif user_input.lower() == "update":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                columns = input("pysql> Enter columns to update: ")
-                args = input("pysql> Enter arguments: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                columns = input(f"({current_db}) pysql> Enter columns to update: ")
+                args = input(f"({current_db}) pysql> Enter arguments: ")
                 result = dml_obj.update(current_db, tb_name, columns, args)
 
                 if result is True:
@@ -327,8 +400,8 @@ while (True):
         elif user_input.lower() == "delete":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                columns = input("pysql> Enter columns to delete: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                columns = input(f"({current_db}) pysql> Enter columns to delete: ")
                 result = dml_obj.delete(current_db, tb_name, columns)
 
                 if result is True:
@@ -350,8 +423,15 @@ while (True):
             print(info.import_)
 
         elif user_input.lower() == "exportdb":
-            db_name = input("pysql> Enter database name: ")
-            path = input("pysql> Enter path to export: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
+                path = input("pysql> Enter path to export: ")
+
             result = exp_obj.export_database(db_name, path)
 
             if result is True:
@@ -360,12 +440,12 @@ while (True):
             else:
                 print(f"[-] Unable to export database {db_name}\n")
 
-        elif user_input.lower() == "exporttb -txt":
+        elif user_input.lower() == "exporttb -json":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                path = input("pysql> Enter path to export: ")
-                result = exp_obj.export_table_txt(current_db, tb_name, path)
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
+                result = exp_obj.export_table_json(current_db, tb_name, path)
 
                 if result is True:
                     print(f"[+] Exported table {tb_name}\n")
@@ -379,8 +459,8 @@ while (True):
         elif user_input.lower() == "exporttb -csv":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                path = input("pysql> Enter path to export: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
                 result = exp_obj.export_table_csv(current_db, tb_name, path)
 
                 if result is True:
@@ -395,8 +475,8 @@ while (True):
         elif user_input.lower() == "exporttb -sql":
 
             if db_use is True:
-                tb_name = input("pysql> Enter table name: ")
-                path = input("pysql> Enter path to export: ")
+                tb_name = input(f"({current_db}) pysql> Enter table name: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
                 result = exp_obj.export_table_sql(current_db, tb_name, path)
 
                 if result is True:
@@ -408,11 +488,11 @@ while (True):
             else:
                 print(f"[-] No database in use")
 
-        elif user_input.lower() == "exportall -txt":
+        elif user_input.lower() == "exportall -json":
 
             if db_use is True:
-                path = input("pysql> Enter path to export: ")
-                result = exp_obj.export_all_txt(current_db, path)
+                path = input(f"({current_db}) pysql> Enter path to export: ")
+                result = exp_obj.export_all_json(current_db, path)
 
                 if result is True:
                     print(f"[+] Exported all tables in {current_db}\n")
@@ -426,7 +506,7 @@ while (True):
         elif user_input.lower() == "exportall -csv":
 
             if db_use is True:
-                path = input("pysql> Enter path to export: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
                 result = exp_obj.export_all_csv(current_db, path)
 
                 if result is True:
@@ -441,7 +521,7 @@ while (True):
         elif user_input.lower() == "exportall -sql":
 
             if db_use is True:
-                path = input("pysql> Enter path to export: ")
+                path = input(f"({current_db}) pysql> Enter path to export: ")
                 result = exp_obj.export_all_sql(current_db, path)
 
                 if result is True:
@@ -454,8 +534,15 @@ while (True):
                 print(f"[-] No database in use\n")
 
         elif user_input.lower() == "importdb":
-            db_name = input("pysql> Enter database name: ")
-            path = input("pysql> Enter path of file: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+                path = input(f"({current_db}) pysql> Enter path of file: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
+                path = input("pysql> Enter path of file: ")
+
             result = imp_obj.import_database(db_name, path)
 
             if result is True:
@@ -465,8 +552,15 @@ while (True):
                 print(f"[-] Unable to import to database {db_name}\n")
 
         elif user_input.lower() == "importtb":
-            db_name = input("pysql> Enter database name: ")
-            path = input("pysql> Enter path of file: ")
+
+            if db_use is True:
+                db_name = input(f"({current_db}) pysql> Enter database name: ")
+                path = input(f"({current_db}) pysql> Enter path of file: ")
+
+            else:
+                db_name = input("pysql> Enter database name: ")
+                path = input("pysql> Enter path of file: ")
+
             result = imp_obj.import_table(db_name, path)
 
             if result is True:
